View source: R/design_augmented.R
| design_augmented | R Documentation |
Fieldbook generator for augmented experimental designs. Every check occurs once in each block and every test entry occurs once in the complete design.
design_augmented(
checks,
entries,
blocks = NULL,
eu_block = NULL,
random = TRUE,
zigzag = FALSE,
dim = NA,
serie = 1000,
seed = NULL,
project = "inkaverse",
qrcode = "{project}{plots}{entry}",
separate_checks = TRUE
)
checks |
Vector of check treatments. |
entries |
Vector of new or test entries. |
blocks |
Optional number of blocks. If |
eu_block |
Number of experimental units per block. It must be greater than the number of checks. |
random |
Logical. Randomize test-entry allocation and positions inside each block. |
zigzag |
Logical. Arrange the physical field layout in zigzag order. |
dim |
Optional physical layout dimensions |
serie |
Base number used to generate plot identifiers. |
seed |
Random seed. |
project |
Barcode prefix. |
qrcode |
QR-code column template. The default is
|
separate_checks |
Logical. When enough positions are available, place
checks in non-adjacent positions inside each block. With
|
A list with fieldbook and parameters.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.