View source: R/design_split_rcbd.R
| design_split_rcbd | R Documentation |
Generate a split-plot design under a randomized complete block design (RCBD) structure for TARPUY.
design_split_rcbd(
nfactors = 2,
factors,
type = "split-rcbd",
rep = 3,
zigzag = FALSE,
nrows = NA,
serie = 1000,
seed = NULL,
project = "inkaverse",
qrcode = "{project}{plots}{factors}"
)
nfactors |
Number of factors in the experiment. Splitplot-RCBD requires exactly two factors. |
factors |
Named list with the factor levels. The first factor is the whole-plot factor and the second factor is the subplot factor. |
type |
Design type. The canonical value is |
rep |
Number of replications or blocks. |
zigzag |
Logical. If |
nrows |
Number of rows in the complete physical layout. The valid
Splitplot-RCBD geometry is |
serie |
Base number used to generate plot identifiers. For example,
|
seed |
Seed used for reproducible randomization. |
project |
Barcode or QR-code prefix. |
qrcode |
Template used to concatenate QR-code fields. The placeholder
|
The first factor is the whole-plot factor and the second factor is the subplot factor. Whole plots are randomized within each block and subplot levels are randomized independently within every whole plot.
A list with fieldbook and parameters.
## Not run:
factors <- list(
Soil = c("S1", "S2", "S3", "S4"),
Fertilizer = c("N1", "N2", "N3", "N4", "N5", "N6")
)
design_split_rcbd(
factors = factors,
rep = 3,
zigzag = TRUE,
seed = 123
)$fieldbook
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.