View source: R/design_repblock.R
| design_repblock | R Documentation |
Function to deploy field-book experiments for completely randomized designs (CRD/DCA) and randomized complete block designs (RCBD/DBCA).
design_repblock(
nfactors = 1,
factors,
type = "crd",
rep = 3,
zigzag = FALSE,
nrows = NA,
serie = 1000,
seed = NULL,
project = "inkaverse",
qrcode = "{project}{plots}"
)
nfactors |
Number of factors in the experiment |
factors |
Named list with the levels of each factor |
type |
Type of experimental arrangement |
rep |
Number of replications or blocks in the experiment
|
zigzag |
Arrange the physical layout in zigzag order |
nrows |
Number of rows in the physical field layout. When missing, the number of replications or blocks is used. |
serie |
Base number used to generate plot identifiers |
seed |
Seed used for reproducible randomization |
project |
Barcode prefix for data collection
|
qrcode |
Template used to concatenate QR-code fields
|
A list with the field-book design and parameters.
## Not run:
library(inti)
factores <- list(
"geno" = c("A", "B", "C", "D", "D", 1, NA, NULL, "NA"),
"salt stress" = c(0, 50, 200, 200, "T0", NA, NULL, "NULL"),
"time" = c(30, 60, 90)
)
fb <- design_repblock(
nfactors = 3,
factors = factores,
type = "rcbd",
rep = 5,
zigzag = TRUE,
seed = 123,
nrows = 5,
qrcode = "{project}{plots}"
)
dsg <- fb$fieldbook
fb %>%
tarpuy_plotdesign(fill = "plots")
fb$parameters
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.